@@ -12,8 +12,8 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 
 /******************************************************************************
  * MAIN
@@ -38,6 +38,13 @@ switch (nvl($mode)) {
 	case "del" :
 		if (!($id == 1)) {
 			delete_category($id);
+			if ($SESSION["frames_used"]) { ?>
+			<script language="JavaScript">
+			<!--
+			parent.categories.location.reload();
+			// -->
+			</script>
+			<? }
 		}
 		break;
 
@@ -49,6 +56,13 @@ switch (nvl($mode)) {
 		validate_category_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			insert_subcategory($id, $HTTP_POST_VARS);
+			if ($SESSION["frames_used"]) { ?>
+			<script language="JavaScript">
+			<!--
+			parent.categories.location.reload();
+			// -->
+			</script>
+			<? }
 //			print_category_list();
 		} else {
 			/* set default values for the reset of the fields */
@@ -75,6 +89,13 @@ switch (nvl($mode)) {
 		if (empty($errormsg)) {
 			update_category($id, $HTTP_POST_VARS);
 			include("templates/category_updated.ihtml");
+			if ($SESSION["frames_used"]) { ?>
+			<script language="JavaScript">
+			<!--
+			parent.categories.location.reload();
+			// -->
+			</script>
+			<? }
 		} else {
 			/* set default values for the reset of the fields */
 			$frm["parent"] = array($HTTP_POST_VARS["parent"]);
@@ -211,18 +232,19 @@ function delete_category($id) {
 			AND pc1.category_id = '$cat->parent_id'
 			AND pc2.category_id = '$id'
 	");
-	$numr = db_num_rows($qid);
-	$toberemoved = "";
-	for ($i=0; $i<$numr-1; $i++) {
-		$appoggio = db_fetch_object($qid, $i);
-		$toberemoved .= "'" . $appoggio->product_id . "', ";
+	if (($numr = db_num_rows($qid)) > 0) {
+		$toberemoved = "";
+		for ($i=0; $i<$numr-1; $i++) {
+			$appoggio = db_fetch_object($qid, $i);
+			$toberemoved .= "'" . $appoggio->product_id . "', ";
+		}
+		$appoggio = db_fetch_object($qid, $numr-1);
+		$toberemoved .= "'" . $appoggio->product_id . "'";
+		$qid = db_query("
+			DELETE FROM products_categories
+			WHERE category_id = '$id' AND product_id IN ($toberemoved)
+		");
 	}
-	$appoggio = db_fetch_object($qid, $numr-1);
-	$toberemoved .= "'" . $appoggio->product_id . "'";
-	$qid = db_query("
-		DELETE FROM products_categories
-		WHERE category_id = '$id' AND product_id IN ($toberemoved)
-	");
 
 	/* re-assign all the products in this category to the parent category */
 	$qid = db_query("
@@ -354,10 +376,9 @@ function import_category($userfile) {
 		/* Empty parent = "Top" */
 		if (strlen(trim($fldarr[0])) == 0)
 			$fldarr[0] = "Top";
-
-		/* Stripping dangerous characters from fields */
-		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
-//echo $fldarr[0] . "<BR>";
+		/* dangerous characters quoting */
+		for ($i=0; $i<4; $i++)
+			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the parent category exists ... */
 		$qid = db_query("
@@ -371,15 +392,6 @@ function import_category($userfile) {
 			$arr = db_fetch_array($qid,0);
 			$pid = $arr[0];
 
-			/* Stripping dangerous characters from fields */
-//			$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
-			$fldarr[1] = ereg_replace("\"","\\\"",$fldarr[1]);
-			$fldarr[1] = ereg_replace("'","\'",$fldarr[1]);
-
-//			$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
-			$fldarr[3] = ereg_replace("'","\'",$fldarr[3]);
-			$fldarr[3] = ereg_replace("\"","\\\"",$fldarr[3]);
-
 			/* ... and let's see if the category already exists ... */
 			$qid = db_query("
 			SELECT id FROM categories WHERE name = '$fldarr[1]'
