@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /* turn on verbose error reporting (15) to see all warnings and errors */
 //error_reporting(15);
@@ -29,13 +29,14 @@ $CFG->dbname = "pgmarket";
 $CFG->dbuser = "postgres";
 $CFG->dbpass = "postgres";
 
-$CFG->myname = "PgMarket 1.3.x";
+$CFG->myname = "PgMarket 1.4.0";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
 $CFG->templatedir = "$CFG->dirroot/templates/";	// with an ending "/"
 $CFG->libdir      = "$CFG->dirroot/lib";	// without an ending "/"
+$CFG->libwww      = "$CFG->wwwroot/lib";	// without an ending "/"
 $CFG->localedir   = "$CFG->dirroot/locale/";	// with an ending "/"
 $CFG->productswww = "$CFG->wwwroot/products/";	// with an ending "/"
 $CFG->productsdir = "$CFG->dirroot/products/";	// with an ending "/"
@@ -85,16 +86,12 @@ if (! isset($SESSION["frames_used"])) {
 if (! isset($SESSION["layersmenu_used"]))
 	$SESSION["layersmenu_used"] = 1;
 $SESSION["brand_used"] = 1;
-$SESSION["iva_used"] = 0;
-$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$SESSION["iva_used"] = 1;
+//$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$IVA = "VAT";
 $SESSION["weight_used"] = 1;
 $SESSION["delivery_used"] = 1;
 
-$SESSION["price_must_be_integer"] = 0;
-	// 1 --> the price must be integer (Italian Lit, for example)
-	// 0 --> the price can be float (US Dollars, for example)
-$SESSION["weightmax"] = 10000.0;
-
 $SESSION["max_file_size_import"] = 10000000;	// upload of import files
 $SESSION["max_file_size_images"] = 500000;	// upload of product images
 
@@ -118,6 +115,9 @@ include ($CFG->global);
 
 //$currency = "Lit";
 $currency = "$";
+$SESSION["price_must_be_integer"] = 0;
+	// 1 --> the price must be integer (Italian Lit, for example)
+	// 0 --> the price can be float (US Dollars, for example)
 function print_formatted_price($price) {
 	global $currency, $lire2euro;
 //	echo $currency . " " . number_format ($price, 0, ",", ".");
@@ -135,6 +135,7 @@ function formatted_price_text($price) {
 }
 
 $weightunity = "Kg";
+$SESSION["weightmax"] = 10000.0;
 function print_formatted_weight($weight) {
 //	echo number_format ($weight, 2, ",", ".");
 	echo number_format ($weight, 2, ".", ",");
@@ -156,7 +157,7 @@ $SESSION["partitaiva_length"] = 11;
 $SESSION["address_length"] = 255;
 $SESSION["number_length"] = 5;
 $SESSION["city_length"] = 100;
-$SESSION["state_length"] = 100;
+$SESSION["country_length"] = 100;
 $SESSION["zip_code_length"] = 5;
 $SESSION["phone_length"] = 32;
 $SESSION["phone_length_min"] = 5;
@@ -188,7 +189,7 @@ $SESSION["users_per_page"] = 10;	// max number of users to be shown per page (ad
 $SESSION["orders_per_page"] = 10;	// max number of orders to be shown per page (admin orders page)
 $SESSION["categories_per_page"] = 10;	// max number of categories to be shown per page (admin orders page)
 $SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (admin brands page)
-$SESSION["iva_per_page"] = 10;		// max number of iva percentuals to be shown per page (admin iva page)
+$SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
 $SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
 
 $ordersdb[Customer]	= "Customer      :";
@@ -205,14 +206,14 @@ $ordersdb[Unit_Price] = "Unit price";
 $ordersdb[Number_of_items] = "Number of items";
 $ordersdb[Delivery] = "Delivery";
 
-$contact[NameOrEnterpriseName] = "Name (Enterprise Name): ";
+$contact[NameOrCompanyName] = "Name (Company Name): ";
 $contact[Address] = "Address:";
 $contact[Phone]         = "Phone:        ";
 $contact[Fax]           = "Fax:          ";
 $contact[MobilePhone]   = "Mobile Phone: ";
 $contact[EMail]         = "E-Mail:       ";
 $contact[AuthData]      = "Authorization for data handling: ";
-$contact[AuthAdvert]    = "Acceptance of advertising matherial: ";
+$contact[AuthAdvert]    = "Acceptance of advertising material: ";
 $contact[Message]       = "Message:";
 
 $myday[1] = "Monday";
@@ -222,7 +223,7 @@ $myday[4] = "Thursday";
 $myday[5] = "Friday";
 $myday[6] = "Saturday";
 $myday[0] = "Sunday";
-        
+
 $mymonth[1] = "January";
 $mymonth[2] = "February";
 $mymonth[3] = "March";
