@@ -12,8 +12,9 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 
 if (!isset($DB_DIE_ON_FAIL)) { $DB_DIE_ON_FAIL = true; }
 if (!isset($DB_DEBUG)) { $DB_DEBUG = false; }
@@ -24,7 +25,7 @@ function db_connect($dbhost, $port, $dbname, $dbuser, $dbpass) {
 
 	global $DB_DIE_ON_FAIL, $DB_DEBUG;
 
-	if (! $dbh = pg_pconnect("host=$dbhost port=$port user=$dbuser password=$dbpass dbname=$dbname")) {
+	if (!($dbh = pg_pconnect("host=$dbhost port=$port user=$dbuser password=$dbpass dbname=$dbname"))) {
 		if ($DB_DEBUG) {
 			echo "<h2>Can't connect to $dbhost as $dbuser</h2>";
 //			echo "<p><b>MySQL Error</b>: ", db_error();
@@ -40,7 +41,7 @@ function db_connect($dbhost, $port, $dbname, $dbuser, $dbpass) {
 	}
 
 /*
-	if (! mysql_select_db($dbname)) {
+	if (!(mysql_select_db($dbname))) {
 		if ($DB_DEBUG) {
 			echo "<h2>Can't select database $dbname</h2>";
 			echo "<p><b>MySQL Error</b>: ", db_error();
@@ -137,6 +138,7 @@ function db_num_rows($qid) {
 //	return mysql_affected_rows();
 //}
 // In PostgreSQL it doesn't exist
+// pg_cmdtuples() could be used instead, with a slightly different meaning...
 
 //function db_insert_id() {
 ///* if you just INSERTed a new row into a table with an autonumber, call this
@@ -160,6 +162,7 @@ function db_num_rows($qid) {
 //	return mysql_num_fields($qid);
 //}
 // In PostgreSQL it doesn't exist
+// pg_numfields could be used instead...
 
 //function db_field_name($qid, $fieldno) {
 ///* return the name of the field number $fieldno returned from the SELECT query
@@ -209,9 +212,9 @@ function find_products($stringtsf_stripped, $case_sensitive=0, $concatenation) {
 	}
 
 	$qid = db_query("
-	SELECT p.* , b.name AS bname
-	FROM products p JOIN brands b ON (p.brand_id = b.id)
-	WHERE $l_search_condition ORDER BY p.name , b.name
+	SELECT p.*, b.name AS bname, i.iva
+	FROM products p, brands b, iva i
+	WHERE p.brand_id = b.id AND p.iva_id = i.id AND $l_search_condition ORDER BY p.name, b.name
 	");
 
 	return $qid;
@@ -357,9 +360,9 @@ function advanced_find_products($frm) {
 	}
 
 	$qid = db_query("
-	SELECT p.* , b.name AS bname
-	FROM products p JOIN brands b ON (p.brand_id = b.id)
-	WHERE $l_search_condition ORDER BY p.name , b.name
+	SELECT p.*, b.name AS bname, i.iva
+	FROM products p, brands b, iva i
+	WHERE p.brand_id = b.id AND p.iva_id = i.id AND $l_search_condition ORDER BY p.name, b.name
 	");
 
 	return $qid;
