@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 function is_logged_in() {
 /* this function will return true if the user has logged in.  a user is logged
@@ -35,7 +35,7 @@ function load_user_profile() {
 	
 	$username = $SESSION["user"]["username"];
         $qid = db_query("SELECT firstname, lastname, usertype, priv,
-				fiscalcode, address, number, city, state, zip_code,
+				fiscalcode, address, number, city, country, zip_code,
 				phone, fax, mobilephone, email, authdata, acceptadvert, notes
 			FROM users
 			WHERE username = '$username'
@@ -107,7 +107,7 @@ function build_catbrowser(&$output, $parent=1, $indent="..") {
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
                 $cat =  db_fetch_object($qid, $i);
-		$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^" . $SESSION["catbrowser_target"] . "\n";
+		$output .= $indent . stripslashes($cat->name) . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^" . $SESSION["catbrowser_target"] . "\n";
                 if ($cat->id != $parent) {
                         build_catbrowser($output, $cat->id, $indent.".");
                 }
@@ -194,7 +194,7 @@ function reset_user_password($username) {
 	/* load up the user record */
 	$qid = db_query("SELECT username, priv, firstname, lastname, email FROM users WHERE username = '$username'");
 	$user = db_fetch_object($qid, 0);
-	if ($user->priv == "admin" || $SESSION["user"]["priv"] != "admin") {
+	if ($user->priv == "admin" || !has_priv("admin")) {
 		return 1;
 	}
 
@@ -227,21 +227,19 @@ function get_category_tree($id=1) {
 
 	global $CFG;
 
-	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id' ORDER BY special_level, name");
+	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id'");
 	if (db_num_rows($qid)) {
 		list($parent, $name) = db_fetch_row($qid, 0);
-		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>$name</a>";
+		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
 	} else {
 		$parent = 1;
 		$name = "";
 	}
 
-	if ($parent > 1) {		
+	if ($parent > 1) {
 		return print_category_tree($parent) . " &gt; " . $name;
-
 	} elseif ($id > 1) {
 		return "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name;
-
 	} elseif ($id == 1) {
 		return "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>";
 	}
@@ -263,7 +261,11 @@ function get_cart_items() {
 		return false;
 	}
 
-	return db_query ("SELECT * FROM products WHERE id IN ($in_clause)");
+	return db_query ("
+			SELECT p.*, i.iva
+			FROM products p, iva i
+			WHERE p.iva_id = i.id AND p.id IN ($in_clause)
+			");
 }
 
 //function chop_ccnum($ccnum) {
@@ -287,7 +289,7 @@ function save_orderinfo(&$frm) {
 	$order->address = $frm["address"];
 	$order->number = $frm["number"];
 	$order->city = $frm["city"];
-	$order->state = $frm["state"];
+	$order->country = $frm["country"];
 	$order->zip_code = $frm["zip_code"];
 //	$order->creditcard = $frm["creditcard"];
 //	$order->expiry = $frm["expiry"];
@@ -629,17 +631,17 @@ function validate_city($city, &$errors, &$msg) {
 	}
 }
 
-function validate_state($state, &$errors, &$msg) {
+function validate_country($country, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
 	include ($CFG->global);
 
-	if (empty($state)) {
-		$errors->state = true;
-		$msg .= "<li>".$empty_state;
-	} else if (strlen($state) > $SESSION["state_length"]) {
-		$errors->state = true;
-		$msg .= "<li>".$state_too_long;
+	if (empty($country)) {
+		$errors->country = true;
+		$msg .= "<li>".$empty_country;
+	} else if (strlen($country) > $SESSION["country_length"]) {
+		$errors->country = true;
+		$msg .= "<li>".$country_too_long;
 	}
 }
 
@@ -961,7 +963,7 @@ function validate_price($price, &$errors, &$msg) {
 	if ($price == "") {
 		$errors->price = true;
 		$msg .= "<li>".$empty_price;
-	} else if ($SESSION["price_must_be_integer"] && (string) ((int) $price) != "$price") {
+	} else if ($SESSION["price_must_be_integer"] && ((string) ((int) $price) != "$price" || (string) $price != str_replace(".", "", $price))) {
 		$errors->price = true;
 		$msg .= "<li>".$price_notint;
 	} else if (!$SESSION["price_must_be_integer"] && (string) ((float) $price) != "$price") {
