@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 function setdefault(&$var, $default="") {
 /* if $var is undefined, set it to $default.  otherwise leave it alone */
@@ -50,11 +50,7 @@ function pvwbr(&$var) {
  * must be called with a variable, for normal strings or functions use p() */
 // finally, it adds <br> instead of \n and echoes some space if the string is empty
 
-/*
-	$appoggio = isset($var) ? htmlSpecialChars(stripslashes($var)) : "";
-	$appoggio = ereg_replace ("\n", "<br>", $appoggio);
-*/
-	$appoggio = nl2br($var);
+	$appoggio = nl2br(stripslashes($var));
 	echo $appoggio == "" ? "&nbsp;" : $appoggio;
 }
 
