@@ -1,7 +1,7 @@
 <?
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
 
 ////////////////////////////////////////////////////////////
 // "Shared" variables
@@ -36,7 +36,8 @@ $The_category = "La categoria";
 $Brand = "Marca";
 $Brands = "Marche";
 $The_brand = "La marca";
-$The_IVA_Percentual = "La percentuale di IVA";
+global $IVA;	// taken from application.inc.php if the scope is a problem
+$The_IVA_Percentage = "La percentuale di " . $IVA;
 $Product = "Prodotto";
 $Products = "Prodotti";
 $The_product = "Il prodotto";
@@ -46,13 +47,13 @@ $Edit_Product = "Modifica prodotto";
 $Items = "pezzi";
 $Add_Subcategory = "Aggiungi sottocategoria";
 $Add_Brand = "Aggiungi marca";
-$Add_IVA = "Aggiungi IVA";
+$Add_IVA = "Aggiungi " . $IVA;
 $back = "indietro";
 $BACK = "INDIETRO";
 $Address = "Via/Piazza";
 $Number = "Numero";
 $City = "Comune";
-$State = "Citt&agrave;";
+$Country = "Citt&agrave;";
 $Zip_Code = "CAP";
 $Phone = "Telefono";
 $Fax = "Fax";
@@ -94,7 +95,7 @@ $Errors = "Errori";
 $Contact_us = "Contattaci !";
 $Signup_Italy = "Iscrizione (Italia)";
 $Signup_non_Italy = "Iscrizione (Estero)";
-$Enterprises_Signup = "Iscrizione Aziende";
+$Companies_Signup = "Iscrizione Aziende";
 $Turn_Off_Frames = "Disabilita frame";
 $Turn_On_Frames = "Abilita frame";
 $Turn_On_Layers_Menu = "Abilita men&ugrave; a layers";
@@ -124,8 +125,8 @@ $Categories_Management = "Amministrazione delle categorie";
 $Import_Categories = "Importa categorie";
 $Brands_Management = "Amministrazione delle marche";
 $Import_Brands = "Importa marche";
-$Import_IVA = "Importa percentuali IVA";
-$IVA_Management = "Amministrazione dei valori di IVA";
+$Import_IVA = "Importa percentuali " . $IVA;
+$IVA_Management = "Amministrazione dei valori di " . $IVA;
 $Orders_Log_ca = "Diario degli ordini - Contrassegno";
 $Orders_Log_cc = "Diario degli ordini - Carta di Credito";
 $Products_Management = "Amministrazione dei prodotti";
@@ -152,7 +153,7 @@ $Discount = "Sconto";
 $Starting_from = "a partire da";
 $C_Add_Category = "[+C] Aggiungi categoria";
 $B_Add_Brand = "[+M] Aggiungi marca";
-$I_Add_IVA = "[+I] Aggiungi percentuale IVA";
+$I_Add_IVA = "[+I] Aggiungi percentuale " . $IVA;
 $P_Add_Product = "[+P] Aggiungi prodotto";
 $Action = "Azione";
 $User = "Utente";
@@ -173,10 +174,10 @@ $Add_a_subcategory_under = "Aggiungi una sottocategoria di";
 $Add_a_product_under = "Aggiungi un prodotto a";
 $Edit_this_category = "Modifica questa categoria";
 $Edit_this_brand = "Modifica questa marca";
-$Edit_this_IVA = "Modifica questa percentuale di IVA";
+$Edit_this_IVA = "Modifica questa percentuale di " . $IVA;
 $admin_footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
 $Brand_reset_for_products = "La marca &egrave; stata azzerata per i prodotti di tale marca";
-$IVA_reset_for_products = "La percentuale di IVA &egrave; stata azzerata per i prodotti con tale IVA";
+$IVA_reset_for_products = "La percentuale di " . $IVA . " &egrave; stata azzerata per i prodotti con tale " . $IVA;
 $Users = "Utenti";
 $Edit_this_order = "Modifica questo ordine";
 $Delete_this_order = "Cancella questo ordine";
@@ -187,7 +188,7 @@ $Ordered = "Ordinato";
 $Ordered_By = "Ordinato da";
 $Amount = "Ammontare";
 $Customer_Info = "Informazioni sul cliente";
-$Enterprise_Id_N = "Partita IVA";
+$Company_Id_N = "Partita IVA";
 $ID = "ID";
 $Current_Price = "Prezzo attuale";
 $Purchase_Price = "Prezzo d'acquisto";
@@ -202,17 +203,17 @@ $Normal = "Normale";
 $Edit_this_product = "Modifica questo prodotto";
 $View_product_details = "Mostra dettagli del prodotto";
 $Privilege = "Privilegio";
-$Enterprise_Name = "Ragione Sociale";
-$Enterprise_identification_number = "Partita IVA";
+$Company_Name = "Ragione Sociale";
+$Company_identification_number = "Partita IVA";
 $Auth_data_handling_az = "Aut. tratt. dati az.";
 $Auth_data_handling_pf = "Aut. tratt. dati pers.";
-$Accept_advert_matherial = "Disp. a ricevere mat. p.";
+$Accept_advert_material = "Disp. a ricevere mat. p.";
 $Registration_Date = "Data iscr.";
 $Authorization_for_data_handling_az = "Autorizzazione al trattamento dei dati aziendali";
 $Authorization_for_data_handling_pf = "Autorizzazione al trattamento dei dati personali";
-$Acceptance_of_advertising_matherial = "Disponibilit&agrave; a ricevere materiale pubblicitario";
+$Acceptance_of_advertising_material = "Disponibilit&agrave; a ricevere materiale pubblicitario";
 $U_Add_User = "[+U] Aggiungi Persona Fisica";
-$U_Add_Enterprise_User = "[+U] Aggiungi Azienda";
+$U_Add_Company_User = "[+U] Aggiungi Azienda";
 $Data_handl = "Tratt. dati";
 $Advert = "Acc. pubbl.";
 $Reset_password_for = "Reinizializza la password di";
@@ -285,9 +286,9 @@ $Min_Username_Length = "(min. ". $SESSION["username_length_min"] . " caratteri)"
 $Old_Password = "Vecchia Password";
 $New_Password = "Nuova Password";
 $Confirm_Password = "Conferma Password";
-$I_agree_with_the_usage_of_the_presently_given_data = "Autorizzo il trattamento dei dati qui forniti";
-$I_accept_to_receive_advertising_matherial = "Accetto di ricevere materiale pubblicitario";
-$I_agree_with_the_usage_of_my_personal_data = "Autorizzo il trattamento dei miei dati personali";
+$I_agree_to_the_usage_of_the_data_provided = "Autorizzo il trattamento dei dati qui forniti";
+$I_accept_advertising_material = "Accetto materiale pubblicitario";
+$I_agree_to_the_use_of_my_personal_data = "Autorizzo il trattamento dei miei dati personali";
 $appoggio = return_star();
 $Please_fill_out_this_contact_form = "Sei pregato di riempire il seguente modulo; tieni presente che &egrave; necessario riempire tutti i campi contrassegnati con un asterisco (" . $appoggio . ").";
 $First_and_Last_Name = "Nome e Cognome<br>(o Ragione Sociale)";
@@ -360,8 +361,8 @@ $number_too_long = "Numero troppo lungo: ".$SESSION["number_length"]." caratteri
 $empty_city = "Non &egrave; stato specificato il comune";
 $city_too_long = "Comune troppo lungo: ".$SESSION["city_length"]." caratteri max";
 
-$empty_state = "Non &egrave; stata specificata la citt&agrave;";
-$state_too_long = "Citt&agrave; troppo lunga: ".$SESSION["state_length"]." caratteri max";
+$empty_country = "Non &egrave; stata specificata la citt&agrave;";
+$country_too_long = "Citt&agrave; troppo lunga: ".$SESSION["country_length"]." caratteri max";
 
 $empty_zip_code = "Riempire il campo del CAP";
 $zip_code_is_zero = "Il CAP deve essere maggiore di zero";
@@ -437,7 +438,7 @@ $brand_name_too_long = "Il nome della marca &egrave; troppo lungo: ".$SESSION["b
 $brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: ".$SESSION["brand_description_length"]." caratteri max";
 
 $Err_ImpBrand = ": La Marca non esiste - '";
-$Err_ImpIVA = ": L'IVA non esiste - '";
+$Err_ImpIVA = ": La " . $IVA . " non esiste - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -458,8 +459,8 @@ $price_is_zero = "Il Prezzo deve essere maggiore di zero";
 $price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
 $price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";
 
-$not_valid_iva = "Valore dell'IVA non valido";
-$iva_not_between_0_and_100 = "L'IVA non &egrave; compresa tra 0 e 100";
+$not_valid_iva = "Valore della " . $IVA . " non valido";
+$iva_not_between_0_and_100 = "La " . $IVA . " non &egrave; compresa tra 0 e 100";
 
 $discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
 $not_valid_discount = "Sconto non valido";
