@@ -1,7 +1,8 @@
 <?
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
+/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */
 
 ////////////////////////////////////////////////////////////
 // "Shared" variables
@@ -36,7 +37,8 @@ $The_category = "The category";
 $Brand = "Brand";
 $Brands = "Brands";
 $The_brand = "The brand";
-$The_IVA_Percentual = "The IVA percentual";
+global $IVA;	// taken from application.inc.php if the scope is a problem
+$The_IVA_Percentage = "The ". $IVA . " percentage";
 $Product = "Product";
 $Products = "Products";
 $The_product = "The product";
@@ -46,13 +48,13 @@ $Edit_Product = "Edit Product";
 $Items = "items";
 $Add_Subcategory = "Add Subcategory";
 $Add_Brand = "Add Brand";
-$Add_IVA = "Add IVA";
+$Add_IVA = "Add " . $IVA;
 $back = "back";
 $BACK = "BACK";
 $Address = "Address";
 $Number = "Number";
 $City = "City";
-$State = "State";
+$Country = "Country / State";
 $Zip_Code = "Zip Code";
 $Phone = "Phone";
 $Fax = "Fax";
@@ -94,7 +96,7 @@ $Errors = "Errors";
 $Contact_us = "Contact us !";
 $Signup_Italy = "Signup (Italy)";
 $Signup_non_Italy = "Signup (outside of Italy)";
-$Enterprises_Signup = "Enterprises Signup";
+$Companies_Signup = "Companies Signup";
 $Turn_Off_Frames = "Turn off frames";
 $Turn_On_Frames = "Turn on frames";
 $Turn_On_Layers_Menu = "Turn on layers menu";
@@ -108,7 +110,7 @@ $Case_Sensitive = "Case Sensitive";
 $Search_excl = "Search !";
 $Insufficient_Privileges = "Insufficient Privileges";
 $No_Orders = "No Orders";
-$No_Such_Order = "There is not any order with the requested identifier";
+$No_Such_Order = "There isn't an order with the requested identifier";
 $PgMarket_Login = $CFG->myname . " Login";
 $PgMarket_Login_Page = $CFG->myname . ": Login Page";
 $sign_up_for_an_account_now = "If you do not already have an account, please sign up for an account now:";
@@ -124,8 +126,8 @@ $Categories_Management = "Category Management";
 $Import_Categories = "Import categories";
 $Brands_Management = "Brands Management";
 $Import_Brands = "Import Brands";
-$Import_IVA = "Import IVA percentuals";
-$IVA_Management = "IVA Management";
+$Import_IVA = "Import " . $IVA . " percentages";
+$IVA_Management = $IVA . " Management";
 $Orders_Log_ca = "Orders Log - Cash On Delivery";
 $Orders_Log_cc = "Orders Log - Credit Card";
 $Products_Management = "Products Management";
@@ -134,7 +136,7 @@ $Save_Changes = "Save Changes";
 $Users_Admin = "Users Management";
 $U_Import_Users = "Import users";
 $_Import_File = "File to be Imported:";
-$Import_Images_Button_Label = "Importa Immagini";
+$Import_Images_Button_Label = "Import Images";
 $Import_Images = "Import Images";
 $End_Import = "Import Completed.";
 $Orders_States_Management = "Orders States Management";
@@ -152,7 +154,7 @@ $Discount = "Discount";
 $Starting_from = "starting from";
 $C_Add_Category = "[+C] Add Category";
 $B_Add_Brand = "[+B] Add Brand";
-$I_Add_IVA = "[+I] Add IVA percentual";
+$I_Add_IVA = "[+I] Add " . $IVA . " percentage";
 $P_Add_Product = "[+P] Add Product";
 $Action = "Action";
 $User = "User";
@@ -173,10 +175,10 @@ $Add_a_subcategory_under = "Add a subcategory under";
 $Add_a_product_under = "Add a product under";
 $Edit_this_category = "Edit this category";
 $Edit_this_brand = "Edit this brand";
-$Edit_this_IVA = "Edit this IVA percentual";
+$Edit_this_IVA = "Edit this " . $IVA . " percentage";
 $admin_footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
 $Brand_reset_for_products = "The Brand has been reset for all products of that brand";
-$IVA_reset_for_products = "The IVA percentual has been reset for all products with that IVA percentual";
+$IVA_reset_for_products = "The " . $IVA . " percentage has been reset for all products with that " . $IVA . " percentage";
 $Users = "Users";
 $Edit_this_order = "Edit this order";
 $Delete_this_order = "Delete this order";
@@ -187,7 +189,7 @@ $Ordered = "Ordered";
 $Ordered_By = "Ordered By";
 $Amount = "Amount";
 $Customer_Info = "Customer Info";
-$Enterprise_Id_N = "Enterprise Id. N.";
+$Company_Id_N = "Company Id. N.";
 $ID = "ID";
 $Current_Price = "Current Price";
 $Purchase_Price = "Purchase Price";
@@ -202,17 +204,17 @@ $Normal = "Normal";
 $Edit_this_product = "Edit this product";
 $View_product_details = "View product details";
 $Privilege = "Privilege";
-$Enterprise_Name = "Enterprise Name";
-$Enterprise_identification_number = "Enterprise identification number";
+$Company_Name = "Company Name";
+$Company_identification_number = "Company identification number";
 $Auth_data_handling_az = "Auth. data h.";
 $Auth_data_handling_pf = "Auth. pers. data h.";
-$Accept_advert_matherial = "Accept. advert. math.";
+$Accept_advert_material = "Accept. advert. mat.";
 $Registration_Date = "Reg. Date";
 $Authorization_for_data_handling_az = "Authorization for data handling";
 $Authorization_for_data_handling_pf = "Authorization for personal data handling";
-$Acceptance_of_advertising_matherial = "Acceptance of advertising matherial";
+$Acceptance_of_advertising_material = "Acceptance of advertising material";
 $U_Add_User = "[+U] Add User";
-$U_Add_Enterprise_User = "[+U] Add Enterprise User";
+$U_Add_Company_User = "[+U] Add Company User";
 $Data_handl = "Data handl.";
 $Advert = "Advert.";
 $Reset_password_for = "Reset password for";
@@ -247,7 +249,7 @@ $None_Male_Singular = "None";
 $Product_not_found = "Product not found";
 $Sorry_product_not_found = "Sorry, the product you are looking for was not found on file.  Please try our <a href=\"".$CFG->wwwroot."/shopping/\">shopping catalog</a> to find what you are looking for.";
 $Purchase_Confirmation = "Purchase Confirmation";
-$Your_shopping_cart_is_empty = "Your shopping cart is empty, <a href=\"".$CFG->wwwroot."/shopping/\">see the product catalog</a>.";
+$Your_shopping_cart_is_empty = "Your shopping cart is empty, <a href=\"".$CFG->wwwroot."/shopping/\">see the products catalog</a>.";
 $Billing_Details = "Billing Details";
 $Date = "Date";
 $Bill_to = "Bill to";
@@ -285,12 +287,12 @@ $Min_Username_Length = "(at least ". $SESSION["username_length_min"] . " charact
 $Old_Password = "Old Password";
 $New_Password = "New Password";
 $Confirm_Password = "Confirm Password";
-$I_agree_with_the_usage_of_the_presently_given_data = "I agree with the usage of the presently given data";
-$I_accept_to_receive_advertising_matherial = "I accept to receive advertising matherial";
-$I_agree_with_the_usage_of_my_personal_data = "I agree with the usage of my personal data";
+$I_agree_to_the_usage_of_the_data_provided = "I agree to the usage of the data provided";
+$I_accept_advertising_material = "I accept advertising material";
+$I_agree_to_the_use_of_my_personal_data = "I agree to the use of my personal data";
 $appoggio = return_star();
 $Please_fill_out_this_contact_form = "Please fill out this contact form; note that all fields labeled with an asterisk (" . $appoggio . ") are required.";
-$First_and_Last_Name = "First and Last Name<br>(or Enterprise Name)";
+$First_and_Last_Name = "First and Last Name<br>(or Company Name)";
 $Message = "Message";
 $Send = "Send";
 
@@ -306,8 +308,8 @@ $the_username = "The Username";
 $already_exists = " is already used";
 
 $empty_username = "Please specify the Username";
-$username_too_long = "Username too much long: ".$SESSION["username_length"]." characters max";
-$username_too_short = "Username too much short: ".$SESSION["username_length_min"]." characters min";
+$username_too_long = "Username too long: ".$SESSION["username_length"]." characters max";
+$username_too_short = "Username too short: ".$SESSION["username_length_min"]." characters min";
 $not_valid_username = "Username not valid: please use only alphanumeric characters";
 
 $passwords_do_not_match = "Passwords do not match";
@@ -317,77 +319,77 @@ $please_enable_javascript =
 For security reasons, to purchase products in our virtual store,
 the use of JavaScript is required.
 <p>
-The JavaScript language, apart from providing functionalities
-very useful for the Web software development, allows to crypt the passwords,
-hence it offers much more security to this store's users.
+The JavaScript language, apart from providing functionalities that are
+very useful for Web software development, also allows the encryption of passwords,
+thus it offers much more security to this store's users.
 <p>
 Hence, to buy products in our virtual store, a browser supporting JavaScript
 is required, as Netscape or Explorer, for example.
 If you are using a browser supporting JavaScript but you have disabled
 such support, please edit your preferences in order to enable JavaScript.
 <p>
-Note: with default options, JavaScript is enabled on Netscape and Explorer.
+Note: JavaScript is enabled by default in Netscape and Explorer.
 </b><br><br>";
 
 $empty_firstname = "Please specify the First Name";
-$firstname_too_long = "First Name too much long: ".$SESSION["firstname_length"]." characters max";
+$firstname_too_long = "First Name too long: ".$SESSION["firstname_length"]." characters max";
 
-$empty_ragionesociale = "Please specify the Ragione Sociale";
-$ragionesociale_too_long = "Ragione Sociale too much long: ".$SESSION["firstname_length"]." characters max";
+$empty_ragionesociale = "Please specify the Company Name";
+$ragionesociale_too_long = "Company Name too long: ".$SESSION["firstname_length"]." characters max";
 
 $empty_lastname = "Please specify your Last Name";
-$lastname_too_long = "Last Name too much long: ".$SESSION["lastname_length"]." characters max";
+$lastname_too_long = "Last Name too long: ".$SESSION["lastname_length"]." characters max";
 
 $empty_name = "Please specify the Name";
-$name_too_long = "Name too much long: ".$SESSION["name_length"]." characters max";
+$name_too_long = "Name too long: ".$SESSION["name_length"]." characters max";
 
 $empty_fiscalcode = "Please specify the Fiscal Code";
-$bad_fiscalcode_length = "Bad Fiscal Code lenght: the Fiscal Code must consist of ".$SESSION["fiscalcode_length"]." alfanumeric characters";
-$not_valid_fiscalcode = "Fiscal Code not valid";
+$bad_fiscalcode_length = "Bad Fiscal Code length: the Fiscal Code must consist of ".$SESSION["fiscalcode_length"]." alphanumeric characters";
+$not_valid_fiscalcode = "Fiscal Code is not valid";
 
-$empty_partitaiva = "Please specify the Enterprise identification number";
-$bad_partitaiva_length = "Bad Enterprise identification number lenght: the Enterprise identification number must consist of ".$SESSION["partitaiva_length"]." ciphers";
-$not_valid_partitaiva = "Enterprise identification number not valid";
+$empty_partitaiva = "Please specify the Company identification number";
+$bad_partitaiva_length = "Bad Company identification number length: the Company identification number must consist of ".$SESSION["partitaiva_length"]." digits";
+$not_valid_partitaiva = "Company identification number not valid";
 
 $empty_address = "Please specify the address";
-$address_too_long = "Address too much long: ".$SESSION["address_length"]." characters max";
+$address_too_long = "Address too long: ".$SESSION["address_length"]." characters max";
 
-$number_too_long = "Number too much long: ".$SESSION["number_length"]." characters max";
+$number_too_long = "Number too long: ".$SESSION["number_length"]." characters max";
 
 $empty_city = "Please specify the city";
-$city_too_long = "City too much long: ".$SESSION["city_length"]." characters max";
+$city_too_long = "City too long: ".$SESSION["city_length"]." characters max";
 
-$empty_state = "Please specify the state";
-$state_too_long = "State too much long: ".$SESSION["state_length"]." characters max";
+$empty_country = "Please specify the country";
+$country_too_long = "Country too long: ".$SESSION["country_length"]." characters max";
 
 $empty_zip_code = "Please specify the Zip Code";
 $zip_code_is_zero = "The Zip Code must be greater than zero";
-$zip_code_notint = "The Zip Code entry must contain an integer number: only ciphers, not any other character";
-$zip_code_length_is_wrong = "The Zip Code must consist of exactly " . $SESSION["zip_code_length"] . " ciphers";
+$zip_code_notint = "The Zip Code entry must contain an integer number: only digits, not any other character";
+$zip_code_length_is_wrong = "The Zip Code must consist of exactly " . $SESSION["zip_code_length"] . " digits";
 
 $empty_phone = "Please specify the phone number";
-$phone_too_long = "Phone number too much long: ".$SESSION["phone_length"]." characters max";
-$phone_too_short = "Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
+$phone_too_long = "Phone number too long: ".$SESSION["phone_length"]." characters max";
+$phone_too_short = "Phone number too short: ".$SESSION["phone_length_min"]." characters min";
 $not_valid_phone = "Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
-$fax_too_long = "Fax number too much long: ".$SESSION["fax_length"]." characters max";
-$fax_too_short = "Fax number too much short: ".$SESSION["fax_length_min"]." characters min";
+$fax_too_long = "Fax number too long: ".$SESSION["fax_length"]." characters max";
+$fax_too_short = "Fax number too short: ".$SESSION["fax_length_min"]." characters min";
 $not_valid_fax = "Fax number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
-$mobilephone_too_long = "Mobile Phone number too much long: ".$SESSION["mobilephone_length"]." characters max";
-$mobilephone_too_short = "Mobile Phone number too much short: ".$SESSION["mobilephone_length_min"]." characters min";
+$mobilephone_too_long = "Mobile Phone number too long: ".$SESSION["mobilephone_length"]." characters max";
+$mobilephone_too_short = "Mobile Phone number too short: ".$SESSION["mobilephone_length_min"]." characters min";
 $not_valid_mobilephone = "Mobile Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
 $empty_email = "Please specify the E-mail address";
-$email_too_long = "E-mail address too much long: ".$SESSION["email_length"]." characters max";
+$email_too_long = "E-mail address too long: ".$SESSION["email_length"]." characters max";
 $not_valid_email = "E-mail address not valid";
 //$the_email_address = "The E-mail address";
 //$email_not_on_file = "The specified email address is not on file";
 
-$notes_too_long = "Notes too much long: ".$SESSION["notes_length"]." characters max";
-$ournotes_too_long = "Notes too much long in the field \"" . $Our_Notes . "\": ".$SESSION["ournotes_length"]." characters max";
-$empty_message = "You did not write any message";
-$message_too_long = "Message too much long: ".$SESSION["message_length"]." characters max";
+$notes_too_long = "Notes too long: ".$SESSION["notes_length"]." characters max";
+$ournotes_too_long = "Notes too long in the field \"" . $Our_Notes . "\": ".$SESSION["ournotes_length"]." characters max";
+$empty_message = "You did not write a message";
+$message_too_long = "Message too long: ".$SESSION["message_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
 // purchase now
@@ -395,12 +397,12 @@ $message_too_long = "Message too much long: ".$SESSION["message_length"]." chara
 
 $empty_customer = "You did not specify the Customer";
 $appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
-$customer_too_long = "Customer too much long: " . $appoggio . " characters max";
+$customer_too_long = "Customer too long: " . $appoggio . " characters max";
 $empty_contact = "You did not specify a Phone to contact you";
-$contact_too_long = "Contact Phone number too much long: ".$SESSION["phone_length"]." characters max";
-$contact_too_short = "Contact Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
+$contact_too_long = "Contact Phone number too long: ".$SESSION["phone_length"]." characters max";
+$contact_too_short = "Contact Phone number too short: ".$SESSION["phone_length_min"]." characters min";
 $not_valid_contact = "Contact Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
-$comments_too_long = "Comments too much long: ".$SESSION["comments_length"]." characters max";
+$comments_too_long = "Comments too long: ".$SESSION["comments_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
 // change password
@@ -416,12 +418,12 @@ $new_passwords_dont_match = "Your new passwords do not match";
 // add and update category
 ////////////////////////////////////////////////////////////
 
-$empty_category_name = "The category name is empty; please fill it";
-$category_name_too_long = "Category Name too much long: ".$SESSION["category_name_length"]." characters max";
-$category_description_too_long = "Category Description too much long: ".$SESSION["category_description_length"]." characters max";
+$empty_category_name = "The category name is empty; please fill it in";
+$category_name_too_long = "Category Name too long: ".$SESSION["category_name_length"]." characters max";
+$category_description_too_long = "Category Description too long: ".$SESSION["category_description_length"]." characters max";
 
-$priv_too_long = "Privilege too much long: ".$SESSION["priv_length"]." characters max";
-$not_valid_priv = "Privilege not valid: please use only alphanumeric characters";
+$priv_too_long = "Privilege too long: ".$SESSION["priv_length"]." characters max";
+$not_valid_priv = "Privilege is not valid: please use only alphanumeric characters";
 
 $Err_ImpCat = ": the Parent Category doesn't exist - '";
 
@@ -430,11 +432,11 @@ $Err_ImpCat = ": the Parent Category doesn't exist - '";
 ////////////////////////////////////////////////////////////
 
 $empty_brand_name = "The brand name is empty; please fill it";
-$brand_name_too_long = "Brand Name too much long: ".$SESSION["brand_name_length"]." characters max";
-$brand_description_too_long = "Brand Description too much long: ".$SESSION["brand_description_length"]." characters max";
+$brand_name_too_long = "Brand Name too long: ".$SESSION["brand_name_length"]." characters max";
+$brand_description_too_long = "Brand Description too long: ".$SESSION["brand_description_length"]." characters max";
 
 $Err_ImpBrand = ": the Brand doesn't exist - '";
-$Err_ImpIVA = ": the IVA doesn't exist - '";
+$Err_ImpIVA = ": the " . $IVA . " doesn't exist - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -444,24 +446,24 @@ $product_id_is_empty = "The ID entry is empty; please fill it";
 $product_id_wspace = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains spaces. Please don't use spaces in product IDs";
 $product_id_wampersand = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains the character \"&amp;\". Please don't use this character in product IDs";
 $product_id_wquestionm = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains the character \"?\". Please don't use this character in product IDs";
-$product_id_too_long = "Product ID too much long: ".$SESSION["product_id_length"]." characters max";
+$product_id_too_long = "Product ID too long: ".$SESSION["product_id_length"]." characters max";
 $the_product_id = "The product ID ";
 
 $empty_product_name = "The product Name is empty; please fill it";
-$product_name_too_long = "Product Name too much long: ".$SESSION["product_name_length"]." characters max";
+$product_name_too_long = "Product Name too long: ".$SESSION["product_name_length"]." characters max";
 
 $empty_price = "Please specify the Price";
 $price_is_zero = "The Price must be greater than zero";
-$price_notint = "The Price entry must contain an integer number: only ciphers, not any other character";
-$price_notfloat = "The Price entry must contain a float number: only ciphers and optionally a dot, not any other character";
+$price_notint = "The Price entry must contain an integer number: only digits, not any other character";
+$price_notfloat = "The Price entry must contain a float number: only digits and optionally a dot, not any other character";
 
-$not_valid_iva = "IVA not valid";
-$iva_not_between_0_and_100 = "The IVA is not between 0 and 100";
+$not_valid_iva = $IVA . " not valid";
+$iva_not_between_0_and_100 = "The " . $IVA . " is not between 0 and 100";
 
 $discount_not_completely_defined = "If you want to discount the product, you have to fill both the fields \"" . $Discount . "\" and \"" . $Starting_from . "\"; if you do not want to discount the product, please leave empty both the fields";
 $not_valid_discount = "Discount not valid";
 $discount_not_between_0_and_100 = "The Discount is not between 0 and 100";
-$discqty_notint = "The \"" . $Starting_from . "\" entry is not an integer number: only ciphers, not any other character";
+$discqty_notint = "The \"" . $Starting_from . "\" entry is not an integer number: only digits, not any other character";
 $discqty_is_negative = "The \"" . $Starting_from . "\" entry can not be a negative number";
 $discqty_is_too_large = "The \"" . $Starting_from . "\" entry is too large: " . $SESSION["discqtymax"] . " max";
 
@@ -471,10 +473,10 @@ $weight_is_zero = "The Weight must be greater than zero";
 $weight_over_max = "Weight too large: " . $SESSION["weightmax"] . " " . $weightunity . " max";
 
 $special_level_empty = "The \"" . $Special_Level . "\" entry is empty; please fill it";
-$special_level_notint = "The \"" . $Special_Level . "\" entry must contain an integer number: only ciphers, not any other character";
+$special_level_notint = "The \"" . $Special_Level . "\" entry must contain an integer number: only digits, not any other character";
 
-$product_description_too_long = "Product Description too much long: ".$SESSION["product_description_length"]." characters max";
-$product_extended_description_too_long = "Product Extended Description too much long: ".$SESSION["product_extended_description_length"]." characters max";
+$product_description_too_long = "Product Description too long: ".$SESSION["product_description_length"]." characters max";
+$product_extended_description_too_long = "Product Extended Description too long: ".$SESSION["product_extended_description_length"]." characters max";
 
 $appoggio = floor ($SESSION["max_file_size_images"] / 1024);
 $no_product_image_chosen = "No new image has been chosen to represent the product, or the submitted image is too large: " . $appoggio . " bytes max";
@@ -486,8 +488,8 @@ $unsupported_image_type = "Unsupported image type";
 ////////////////////////////////////////////////////////////
 
 $empty_order_state_name = "The Order State Name is empty; please fill it";
-$order_state_name_too_long = "Order State Name too much long: ".$SESSION["order_state_name_length"]." characters max";
-$order_state_description_too_long = "Order State Description too much long: ".$SESSION["order_state_description_length"]." characters max";
+$order_state_name_too_long = "Order State Name too long: ".$SESSION["order_state_name_length"]." characters max";
+$order_state_description_too_long = "Order State Description too long: ".$SESSION["order_state_description_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
 // advanced search
