@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -103,7 +103,7 @@ function create_order_ca(&$order, &$emailbody) {
 		  $ordersdb[Customer] . " $order->customer\n"
 		. $ordersdb[Phone]    . " $order->contact\n"
 		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
-		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";
+		. " $order->city\n" . " $order->country\n" . " $order->zip_code\n";
 
 	/* save order information first */
 
@@ -141,7 +141,6 @@ function create_order_ca(&$order, &$emailbody) {
 	$numr = db_num_rows($qid);
         for ($i=0; $i<$numr; $i++) {
 		$item = db_fetch_object($qid, $i);
-		$ivavalue = get_iva($item->iva_id);
 		db_query("
 		INSERT INTO order_items (
 			order_id, product_id, price, iva, weight, qty
@@ -149,7 +148,7 @@ function create_order_ca(&$order, &$emailbody) {
 			 '$orderid'
 			,'$item->id'
 			,'$item->price'
-			,'$ivavalue'
+			,'$item->iva'
 			,'$item->weight'
 			,'{$CART->items["$item->id"]}'
 		)");
@@ -184,7 +183,7 @@ function create_order_cc(&$order, $passwordric) {
 		  $ordersdb[Customer] . " $order->customer\n"
 		. $ordersdb[Phone]    . " $order->contact\n"
 		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
-		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";
+		. " $order->city\n" . " $order->country\n" . " $order->zip_code\n";
 
 	/* save order information first */
 
@@ -215,7 +214,6 @@ function create_order_cc(&$order, $passwordric) {
 	$numr = db_num_rows($qid);
         for ($i=0; $i<$numr; $i++) {
 		$item = db_fetch_object($qid, $i);
-		$ivavalue = get_iva($item->iva_id);
 		db_query("
 		INSERT INTO order_items (
 			order_id, product_id, price, iva, weight, qty
@@ -223,7 +221,7 @@ function create_order_cc(&$order, $passwordric) {
 			 '$orderid'
 			,'$item->id'
 			,'$item->price'
-			,'$ivavalue'
+			,'$item->iva'
 			,'$item->weight'
 			,'{$CART->items["$item->id"]}'
 		)");
