@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -52,24 +52,21 @@ function get_products($category_id=1) {
 	$qid = db_query("
 	SELECT
 		 p.id
-		,p.name
+		,p.name AS name
 		,p.price
-		,p.iva_id
 		,p.discount
 		,p.discqty
 		,p.weight
 		,p.special_flag
 		,p.special_level
 		,p.description
-		,p.imagetype
-		,p.imagewidth
-		,p.imageheight
 		,p.thumbwidth
 		,p.thumbheight
 		,pc.category_id
 		,b.name AS bname
-	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
-	WHERE pc.category_id = '$category_id'
+		,i.iva
+	FROM products p, products_categories pc, brands b, iva i
+	WHERE p.id = pc.product_id AND p.brand_id = b.id AND p.iva_id = i.id AND pc.category_id = '$category_id'
 	ORDER BY p.special_level ASC
 	");
 
