@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -63,13 +63,11 @@ function load_product($product_id) {
 		 p.id
 		,p.name AS name
 		,p.price
-		,p.iva_id
 		,p.discount
 		,p.discqty
 		,p.weight
 		,p.special_flag
 		,p.special_level
-		,p.description
 		,p.extended_description
 		,p.imagetype
 		,p.imagewidth
@@ -78,11 +76,12 @@ function load_product($product_id) {
 		,p.thumbheight
 		,pc.category_id
 		,b.name AS bname
-	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
-	WHERE p.id = '$product_id'
+		,i.iva
+	FROM products p, products_categories pc, brands b, iva i
+	WHERE p.id = pc.product_id AND p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
 	");
 
-	if ($qid) {
+	if (db_num_rows($qid) > 0) {
 		return db_fetch_object($qid, 0);
 	} else {
 		return false;
