@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -42,19 +42,19 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	$frm["address"] = $user->address;	
 	$frm["number"] = $user->number;
 	$frm["city"] = $user->city;
-	$frm["state"] = $user->state;
+	$frm["country"] = $user->country;
 	$frm["zip_code"] = $user->zip_code;
 }
 
 if ($info = load_orderinfo()) {
-	$customer = $info->customer;
-	$contact = $info->contact;
-	$address = $info->address;
-	$number = $info->number;
-	$city = $info->city;
-	$state = $info->state;
-	$zip_code = $info->zip_code;
-	$comments = $info->comments;
+	$frm["customer"] = $info->customer;
+	$frm["contact"] = $info->contact;
+	$frm["address"] = $info->address;
+	$frm["number"] = $info->number;
+	$frm["city"] = $info->city;
+	$frm["country"] = $info->country;
+	$frm["zip_code"] = $info->zip_code;
+	$frm["comments"] = $info->comments;
 }
 
 include("$CFG->templatedir"."header.ihtml");
@@ -81,7 +81,7 @@ function validate_form(&$frm, &$errors) {
 	validate_address($frm["address"], &$errors, &$msg);
 	validate_number($frm["number"], &$errors, &$msg);
 	validate_city($frm["city"], &$errors, &$msg);
-	validate_state($frm["state"], &$errors, &$msg);
+	validate_country($frm["country"], &$errors, &$msg);
 	validate_zip_code($frm["zip_code"], &$errors, &$msg);
 	validate_comments($frm["comments"], &$errors, &$msg);
 
@@ -96,7 +96,7 @@ function load_userinfo() {
 	global $SESSION;
  
 	$qid = db_query("SELECT firstname, lastname, phone,
-				address, number, city, state, zip_code
+				address, number, city, country, zip_code
 			FROM users
 			WHERE username = '{$SESSION["user"]["username"]}'");
 	return db_fetch_object($qid, 0);
