@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -80,7 +80,7 @@ function validate_form(&$frm, &$errors, $usertype) {
 	validate_address($frm["address"], &$errors, &$msg);
 	validate_number($frm["number"], &$errors, &$msg);
 	validate_city($frm["city"], &$errors, &$msg);
-	validate_state($frm["state"], &$errors, &$msg);
+	validate_country($frm["country"], &$errors, &$msg);
 	validate_zip_code($frm["zip_code"], &$errors, &$msg);
 	validate_phone($frm["phone"], &$errors, &$msg);
 	validate_fax($frm["fax"], &$errors, &$msg);
@@ -119,7 +119,7 @@ function insert_user(&$frm, $usertype) {
 		,address
 		,number
 		,city
-		,state
+		,country
 		,zip_code
 		,phone
 		,fax
@@ -140,7 +140,7 @@ function insert_user(&$frm, $usertype) {
 		,'$frm[address]'
 		,'$frm[number]'
 		,'$frm[city]'
-		,'$frm[state]'
+		,'$frm[country]'
 		,'$frm[zip_code]'
 		,'$frm[phone]'
 		,'$frm[fax]'
